==> circumstellar-0.1.0.tar.gz: lib/src/discord_client.dart <==
import 'dart:async';

import 'package:circumstellar/src/models/event_dispatcher.dart';
import 'package:circumstellar/src/rest/discord_rest.dart';
import 'package:circumstellar/src/rest/request_options.dart';
import 'package:circumstellar/src/rest/rest_response.dart';
import 'package:circumstellar/src/ws/discord_ws.dart';
import 'package:w_transport/w_transport.dart';

import 'discord_constants.dart';

import 'models/auth_set.dart';

/// Represents a connection to the two Discord APIs.
class DiscordClient {
  /// The current authentication properties.
  DiscordAuthSet auth;

  /// The w_transport transport platform - either VM or Web.
  TransportPlatform transportPlatform;

  /// The current WebSocket wrapper.
  DiscordWebSocketClient ws;

  /// The current REST wrapper.
  RestClient rest;

  /// The current event dispatcher.
  EventDispatcher dispatcher;

  /// Default constructor.
  DiscordClient(this.auth, this.transportPlatform) {
    this.rest = new RestClient(this);
    this.ws = new DiscordWebSocketClient(this, rest);
    this.dispatcher = new EventDispatcher(this);
  }

  /// Starts the WebSocket and REST APIs and attempts to contact Discord.
  Future start() async {
    await this.ws.connect();
  }

  /// Stops all APIs.
  void stop() {
    this.ws.stop();
  }

  // Utility functions

  /// Creates a message in the specified channel (ID)
  Future<RestRequestResult> createMessage(String channelId, String contentArg,
      {bool tts = false,
      Map<String, dynamic> embed = null,
      RequestOptions options = null}) async {
    return await this.rest.executeRoute(
        ApiRoutes.channels.createMessage(channelId),
        {'content': contentArg, 'embed': embed});
  }
}

==> circumstellar-0.1.22.tar.gz: lib/src/discord_client.dart <==
/**
 * discord_client.dart
 * Circumstellar - Client
 * 
 * Created by Jackson Rakena
 * Copyright (c) 2018 Jackson Rakena. All rights reserved.
 * Part of the Circumstellar project, licensed under a 3-Clause BSD License (under LICENSE)
 */

part of circumstellar;

/// Represents a connection to the two Discord APIs.
class DiscordClient {
  /// The current authentication properties.
  DiscordAuthSet auth;

  /// The w_transport transport platform - either VM or Web.
  transport.TransportPlatform transportPlatform;

  /// The current WebSocket wrapper.
  DiscordWebSocketClient ws;

  /// The current REST wrapper.
  RestClient rest;

  /// The current event dispatcher.
  EventDispatcher dispatcher;

  /// The current entity manager.
  EntityManager entities;

  /// Default constructor.
  DiscordClient(this.auth, this.transportPlatform) {
    this.rest = new RestClient(this);
    this.ws = new DiscordWebSocketClient(this, rest);
    this.dispatcher = new EventDispatcher(this);
    this.entities = new EntityManager(this);
  }

  /// Starts the WebSocket and REST APIs and attempts to contact Discord.
  Future start() async {
    await this.ws.connect();
  }

  /// Stops all APIs.
  void stop() {
    this.ws.stop();
  }

  // Utility functions

  /// Creates a message in the specified channel (ID)
  Future<Message> createMessage(String channelId, String contentArg,
      {bool tts = false,
      Map<String, dynamic> embed = null,
      RequestOptions options = null}) async {
    var response = await this.rest.executeRoute(
        ApiRoutes.channels.createMessage(channelId),
        {'content': contentArg, 'embed': embed});
    var msg = new Message(this);
    await msg.updateModel(response.json, this);
    return msg;
  }
}
